@@ -3,9 +3,8 @@ use warnings;
 package Net::PcapWriter;
 use Time::HiRes 'gettimeofday';
 use Net::PcapWriter::TCP;
-use Net::PcapWriter::UDP;
 
-our $VERSION = '0.710_2';
+our $VERSION = 0.1;
 
 sub new {
 	my ($class,$file) = @_;
@@ -43,7 +42,8 @@ sub _header {
 		2,4,        # major, minor
 		0,0,        # timestamps correction and accuracy
 		0xffff,     # snaplen
-		1,          # DLT_EN10MB
+		# DLT_RAW is 12, but not on OpenBSD and BSD/OS (14)
+		$^O =~/OpenBSD/i ? 14:12,  
 	);
 }
 
@@ -66,16 +66,6 @@ sub packet {
 		$tsec = int($timestamp);
 		$tmsec = int(($timestamp - $tsec)*1_000_000);
 	}
-
-	# add ethernet framing so that we can use DLT_EN10MB
-	# DLT_RAW is nicer, but different systems have different ideas about
-	# the type id :(
-	$data = pack("NnNnna*",
-	    0,1,0,1, # all macs 0:*
-	    0x0800, # ETH_TYPE_IP
-	    $data,
-	);
-
 	print {$self->{fh}} pack('LLLLa*',
 		$tsec,$tmsec,       # struct timeval ts
 		length($data),      # caplen
@@ -91,12 +81,6 @@ sub tcp_conn {
 	return Net::PcapWriter::TCP->new($self,$src,$sport,$dst,$dport);
 }
 
-# return new UDP connection object
-sub udp_conn {
-	my ($self,$src,$sport,$dst,$dport) = @_;
-	return Net::PcapWriter::UDP->new($self,$src,$sport,$dst,$dport);
-}
-
 1;
 
 __END__
@@ -179,18 +163,6 @@ Will call shutdown for both C<$dir> before destroying connection object.
 
 =back
 
-=item $writer->tcp_conn($src,$sport,$dst,$dport)
-
-Will return C<Net::PcapWriter::TCP> object, which then provides the following
-methods:
-
-=item $tcpconn->write($dir,$data,[$timestamp])
-
-Will write the given data for the direction C<$dir> (0 are data from client to
-server, 1 the other way). Will write TCP handshake if not done yet.
-
-=back
-
 =back
 
 =head1 BUGS
@@ -199,4 +171,4 @@ Only supports IPv4 at the moment.
 
 =head1 AUTHOR
 
-Steffen Ullrich <sullr@cpan.org>
+Steffen Ullrich <Steffen_Ullrich@GeNUA.de>
