@@ -1,26 +1,9 @@
 use strict;
 use warnings;
-package Net::PcapWriter::IP;
-use Socket qw(AF_INET);
-
-BEGIN { 
-	# inet_pton is in Socket since 5.12
-	# but even if it is in Socket it can throw a non-implemented error
-	eval { 
-		Socket->import('inet_pton'); 
-		inet_pton(AF_INET,'127.0.0.1'); 
-		1 
-	} or eval { 
-		require Socket6; 
-		Socket6->import('inet_pton');
-		inet_pton(AF_INET,'127.0.0.1');
-		1 
-	} or die "you need either a modern perl or Socket6"
-}
-
+use Net::PcapWriter::IP;
+use Socket qw(inet_pton AF_INET);
 use base 'Exporter';
-# re-export the usable inet_pton
-our @EXPORT = qw(ip_chksum ip4_packet inet_pton);
+our @EXPORT = qw(ip_chksum ip4_packet);
 
 # write IPv4 packet
 sub ip4_packet {
